[kaffe] CVS kaffe (robilad): Resynced with GNU Classpath: awt and swing fixes
Kaffe CVS
cvs-commits at kaffe.org
Wed Jul 6 06:30:35 PDT 2005
PatchSet 6705
Date: 2005/07/06 13:21:11
Author: robilad
Branch: HEAD
Tag: (none)
Log:
Resynced with GNU Classpath: awt and swing fixes
Members:
ChangeLog:1.4229->1.4230
libraries/javalib/java/awt/AWTKeyStroke.java:1.8->1.9
libraries/javalib/java/awt/BufferCapabilities.java:1.7->1.8
libraries/javalib/java/awt/ColorPaintContext.java:1.4->1.5
libraries/javalib/java/awt/Component.java:1.54->1.55
libraries/javalib/java/awt/Container.java:1.34->1.35
libraries/javalib/java/awt/EventQueue.java:1.17->1.18
libraries/javalib/java/awt/GraphicsDevice.java:1.4->1.5
libraries/javalib/java/awt/Image.java:1.22->1.23
libraries/javalib/java/awt/KeyboardFocusManager.java:1.10->1.11
libraries/javalib/java/awt/MediaTracker.java:1.20->1.21
libraries/javalib/java/awt/PrintJob.java:1.5->1.6
libraries/javalib/java/awt/Robot.java:1.6->1.7
libraries/javalib/javax/swing/JTable.java:1.23->1.24
Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.4229 kaffe/ChangeLog:1.4230
--- kaffe/ChangeLog:1.4229 Wed Jul 6 02:40:33 2005
+++ kaffe/ChangeLog Wed Jul 6 13:21:11 2005
@@ -2,6 +2,31 @@
Resynced with GNU Classpath.
+ 2005-07-06 David Gilbert <david.gilbert at object-refinery.com>
+
+ * java/awt/AWTKeyStroke.java: fixed API doc links,
+ * java/awt/BufferCapabilities.java: likewise,
+ * java/awt/ColorPaintContext.java: likewise,
+ * java/awt/Component.java: likewise,
+ * java/awt/Container.java: likewise,
+ * java/awt/EventQueue.java: likewise,
+ * java/awt/GraphicsDevice.java: likewise,
+ * java/awt/Image.java: likewise,
+ * java/awt/KeyboardFocusManager.java: likewise,
+ * java/awt/MediaTracker.java: likewise,
+ * java/awt/PrintJob.java: likewise,
+ * java/awt/Robot.java: likewise.
+
+ 2005-07-06 David Gilbert <david.gilbert at object-refinery.com>
+
+ * javax/swing/JTable.java
+ (setAutoCreateColumnsFromModel): when the flag changes from false to
+ true, call createDefaultColumnsFromModel().
+
+2005-07-06 Dalibor Topic <robilad at kaffe.org>
+
+ Resynced with GNU Classpath.
+
2005-07-05 David Gilbert <david.gilbert at object-refinery.com>
* javax/swing/JTable.java
Index: kaffe/libraries/javalib/java/awt/AWTKeyStroke.java
diff -u kaffe/libraries/javalib/java/awt/AWTKeyStroke.java:1.8 kaffe/libraries/javalib/java/awt/AWTKeyStroke.java:1.9
--- kaffe/libraries/javalib/java/awt/AWTKeyStroke.java:1.8 Mon Jul 4 00:06:00 2005
+++ kaffe/libraries/javalib/java/awt/AWTKeyStroke.java Wed Jul 6 13:21:16 2005
@@ -38,6 +38,7 @@
package java.awt;
+import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.io.ObjectStreamException;
import java.io.Serializable;
Index: kaffe/libraries/javalib/java/awt/BufferCapabilities.java
diff -u kaffe/libraries/javalib/java/awt/BufferCapabilities.java:1.7 kaffe/libraries/javalib/java/awt/BufferCapabilities.java:1.8
--- kaffe/libraries/javalib/java/awt/BufferCapabilities.java:1.7 Mon Jul 4 00:06:01 2005
+++ kaffe/libraries/javalib/java/awt/BufferCapabilities.java Wed Jul 6 13:21:16 2005
@@ -38,6 +38,8 @@
package java.awt;
+import java.awt.image.BufferStrategy;
+
/**
* A double-buffering capability descriptor. This class exposes
* details about the double-buffering algorithms used by image
@@ -60,7 +62,7 @@
* @author Eric Blake (ebb9 at email.byu.edu)
*
* @see BufferStrategy#getCapabilities()
- * @see GraphicsConfiguration#getCapabilities()
+ * @see GraphicsConfiguration#getBufferCapabilities()
*
* @since 1.4
*/
Index: kaffe/libraries/javalib/java/awt/ColorPaintContext.java
diff -u kaffe/libraries/javalib/java/awt/ColorPaintContext.java:1.4 kaffe/libraries/javalib/java/awt/ColorPaintContext.java:1.5
--- kaffe/libraries/javalib/java/awt/ColorPaintContext.java:1.4 Mon Jul 4 00:06:01 2005
+++ kaffe/libraries/javalib/java/awt/ColorPaintContext.java Wed Jul 6 13:21:16 2005
@@ -105,8 +105,8 @@
*
* @param x the x-coordinate, in device space
* @param y the y-coordinate, in device space
- * @param w the width, in device space
- * @param h the height, in device space
+ * @param width the width, in device space
+ * @param height the height, in device space
* @return a raster for the given area and color
*/
public Raster getRaster(int x, int y, int width, int height)
Index: kaffe/libraries/javalib/java/awt/Component.java
diff -u kaffe/libraries/javalib/java/awt/Component.java:1.54 kaffe/libraries/javalib/java/awt/Component.java:1.55
--- kaffe/libraries/javalib/java/awt/Component.java:1.54 Mon Jul 4 00:06:01 2005
+++ kaffe/libraries/javalib/java/awt/Component.java Wed Jul 6 13:21:16 2005
@@ -3500,9 +3500,9 @@
/**
* Sets the focus traversal keys for one of the three focus
* traversal directions supported by Components:
- * {@link #KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS},
- * {@link #KeyboardFocusManager.BACKWARD_TRAVERSAL_KEYS}, or
- * {@link #KeyboardFocusManager.UP_CYCLE_TRAVERSAL_KEYS}. Normally, the
+ * {@link KeyboardFocusManager#FORWARD_TRAVERSAL_KEYS},
+ * {@link KeyboardFocusManager#BACKWARD_TRAVERSAL_KEYS}, or
+ * {@link KeyboardFocusManager#UP_CYCLE_TRAVERSAL_KEYS}. Normally, the
* default values should match the operating system's native
* choices. To disable a given traversal, use
* <code>Collections.EMPTY_SET</code>. The event dispatcher will
Index: kaffe/libraries/javalib/java/awt/Container.java
diff -u kaffe/libraries/javalib/java/awt/Container.java:1.34 kaffe/libraries/javalib/java/awt/Container.java:1.35
--- kaffe/libraries/javalib/java/awt/Container.java:1.34 Mon Jul 4 00:06:02 2005
+++ kaffe/libraries/javalib/java/awt/Container.java Wed Jul 6 13:21:17 2005
@@ -269,7 +269,7 @@
*
* @return The same component that was added.
*
- * @throws ArrayIndexOutOfBounds If the specified index is invalid.
+ * @throws ArrayIndexOutOfBoundsException If the specified index is invalid.
*/
public Component add(Component comp, int index)
{
@@ -300,7 +300,7 @@
* @param index The index in the component list to insert this child
* at, or -1 to add at the end of the list.
*
- * @throws ArrayIndexOutOfBounds If the specified index is invalid.
+ * @throws ArrayIndexOutOfBoundsException If the specified index is invalid.
*/
public void add(Component comp, Object constraints, int index)
{
@@ -320,7 +320,7 @@
* @param index The index in the component list to insert this child
* at, or -1 to add at the end of the list.
*
- * @throws ArrayIndexOutOfBounds If the specified index is invalid.
+ * @throws ArrayIndexOutOfBoundsException If the specified index is invalid.
*/
protected void addImpl(Component comp, Object constraints, int index)
{
@@ -436,7 +436,7 @@
/**
* Removes the specified component from this container.
*
- * @return component The component to remove from this container.
+ * @param comp The component to remove from this container.
*/
public void remove(Component comp)
{
@@ -1367,7 +1367,7 @@
* however, ContainerOrderFocusTraversalPolicy is in effect, and it
* supports implicit down-cycle traversal operations.
*
- * @return true if this is a focus cycle root, false otherwise
+ * @param focusCycleRoot true if this is a focus cycle root, false otherwise
*
* @since 1.4
*/
Index: kaffe/libraries/javalib/java/awt/EventQueue.java
diff -u kaffe/libraries/javalib/java/awt/EventQueue.java:1.17 kaffe/libraries/javalib/java/awt/EventQueue.java:1.18
--- kaffe/libraries/javalib/java/awt/EventQueue.java:1.17 Mon Jul 4 00:06:03 2005
+++ kaffe/libraries/javalib/java/awt/EventQueue.java Wed Jul 6 13:21:17 2005
@@ -42,6 +42,7 @@
import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
+import java.awt.event.InputMethodEvent;
import java.awt.event.InvocationEvent;
import java.awt.event.WindowEvent;
import java.lang.reflect.InvocationTargetException;
Index: kaffe/libraries/javalib/java/awt/GraphicsDevice.java
diff -u kaffe/libraries/javalib/java/awt/GraphicsDevice.java:1.4 kaffe/libraries/javalib/java/awt/GraphicsDevice.java:1.5
--- kaffe/libraries/javalib/java/awt/GraphicsDevice.java:1.4 Mon Jul 4 00:06:05 2005
+++ kaffe/libraries/javalib/java/awt/GraphicsDevice.java Wed Jul 6 13:21:17 2005
@@ -38,6 +38,8 @@
package java.awt;
+import java.awt.image.VolatileImage;
+
/**
* This describes a graphics device available to the given environment. This
* includes screen and printer devices, and the different configurations for
@@ -163,8 +165,8 @@
*
* @param w the window to toggle
* @see #isFullScreenSupported()
- * @see getFullScreenWindow()
- * @see setDisplayMode(DisplayMode)
+ * @see #getFullScreenWindow()
+ * @see #setDisplayMode(DisplayMode)
* @see Component#enableInputMethods(boolean)
* @since 1.4
*/
Index: kaffe/libraries/javalib/java/awt/Image.java
diff -u kaffe/libraries/javalib/java/awt/Image.java:1.22 kaffe/libraries/javalib/java/awt/Image.java:1.23
--- kaffe/libraries/javalib/java/awt/Image.java:1.22 Mon Jul 4 00:06:05 2005
+++ kaffe/libraries/javalib/java/awt/Image.java Wed Jul 6 13:21:17 2005
@@ -94,7 +94,7 @@
* Constant indicating that the area averaging scaling algorithm should be
* used.
*
- * @see AreaAveragingScaleFilter
+ * @see java.awt.image.AreaAveragingScaleFilter
* @since 1.1
*/
public static final int SCALE_AREA_AVERAGING = 16;
@@ -141,7 +141,7 @@
* This method is only valid for off-screen objects.
*
* @return a graphics context object for an off-screen object
- * @see Graphics#createImage(int, int)
+ * @see Graphics#getcreateImage(int, int)
*/
public abstract Graphics getGraphics();
Index: kaffe/libraries/javalib/java/awt/KeyboardFocusManager.java
diff -u kaffe/libraries/javalib/java/awt/KeyboardFocusManager.java:1.10 kaffe/libraries/javalib/java/awt/KeyboardFocusManager.java:1.11
--- kaffe/libraries/javalib/java/awt/KeyboardFocusManager.java:1.10 Mon Jul 4 00:06:05 2005
+++ kaffe/libraries/javalib/java/awt/KeyboardFocusManager.java Wed Jul 6 13:21:17 2005
@@ -38,8 +38,10 @@
package java.awt;
+import java.applet.Applet;
import java.awt.event.FocusEvent;
import java.awt.event.KeyEvent;
+import java.awt.event.WindowEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyVetoException;
@@ -335,8 +337,8 @@
* @param owner the Component to return from getFocusOwner and
* getGlobalFocusOwner
*
- * @see Component.requestFocus ()
- * @see Component.requestFocusInWindow ()
+ * @see Component#requestFocus()
+ * @see Component#requestFocusInWindow()
*/
protected void setGlobalFocusOwner (Component owner)
{
@@ -419,8 +421,8 @@
* @param focusOwner the Component to return from
* getPermanentFocusOwner and getGlobalPermanentFocusOwner
*
- * @see Component.requestFocus ()
- * @see Component.requestFocusInWindow ()
+ * @see Component#requestFocus()
+ * @see Component#requestFocusInWindow()
*/
protected void setGlobalPermanentFocusOwner (Component focusOwner)
{
Index: kaffe/libraries/javalib/java/awt/MediaTracker.java
diff -u kaffe/libraries/javalib/java/awt/MediaTracker.java:1.20 kaffe/libraries/javalib/java/awt/MediaTracker.java:1.21
--- kaffe/libraries/javalib/java/awt/MediaTracker.java:1.20 Mon Jul 4 00:06:06 2005
+++ kaffe/libraries/javalib/java/awt/MediaTracker.java Wed Jul 6 13:21:17 2005
@@ -48,7 +48,7 @@
* Media objects are tracked by assigning them an ID. It is possible
* to assign the same ID to mutliple objects, effectivly grouping them
* together. In this case the status flags ({@link #statusID}) and error flag
- * (@link #isErrorID} and {@link #getErrorId}) are ORed together. This
+ * (@link #isErrorID} and {@link #getErrorsID}) are ORed together. This
* means that you cannot say exactly which media object has which status,
* at most you can say that there <em>are</em> certain media objects with
* some certain status.
@@ -123,7 +123,7 @@
* @return <code>true</code> if more data is needed, <code>false</code>
* otherwise
*
- * @see {@link java.awt.image.ImageObserver}
+ * @see java.awt.image.ImageObserver
*/
public boolean imageUpdate(Image img, int flags, int x, int y,
int width, int height)
Index: kaffe/libraries/javalib/java/awt/PrintJob.java
diff -u kaffe/libraries/javalib/java/awt/PrintJob.java:1.5 kaffe/libraries/javalib/java/awt/PrintJob.java:1.6
--- kaffe/libraries/javalib/java/awt/PrintJob.java:1.5 Mon Jul 4 00:06:06 2005
+++ kaffe/libraries/javalib/java/awt/PrintJob.java Wed Jul 6 13:21:17 2005
@@ -38,6 +38,8 @@
package java.awt;
+import java.util.Properties;
+
/**
* This abstract class represents a print job.
*
Index: kaffe/libraries/javalib/java/awt/Robot.java
diff -u kaffe/libraries/javalib/java/awt/Robot.java:1.6 kaffe/libraries/javalib/java/awt/Robot.java:1.7
--- kaffe/libraries/javalib/java/awt/Robot.java:1.6 Mon Jul 4 00:06:07 2005
+++ kaffe/libraries/javalib/java/awt/Robot.java Wed Jul 6 13:21:17 2005
@@ -53,7 +53,7 @@
* create self-running demo programs.
*
* Since Robot generates native windowing system events, rather than
- * simply inserting {@link AWTEvents} on the AWT event queue, its use
+ * simply inserting {@link AWTEvent}s on the AWT event queue, its use
* is not restricted to Java programs. It can be used to
* programatically drive any graphical application.
*
@@ -227,7 +227,7 @@
/**
* Press a key.
*
- * @param keycode key to press, a {@link KeyEvent} VK_ constant
+ * @param keycode key to press, a {@link java.awt.event.KeyEvent} VK_ constant
*
* @exception IllegalArgumentException if keycode is not a valid key
*/
@@ -245,7 +245,8 @@
/**
* Release a key.
*
- * @param keycode key to release, a {@link KeyEvent} VK_ constant
+ * @param keycode key to release, a {@link java.awt.event.KeyEvent} VK_
+ * constant
*
* @exception IllegalArgumentException if keycode is not a valid key
*/
@@ -312,7 +313,7 @@
}
/**
- * Check if this Robot automatically calls {@link waitForIdle} after
+ * Check if this Robot automatically calls {@link #waitForIdle()} after
* generating an event.
*
* @return true if waitForIdle is automatically called
@@ -324,7 +325,7 @@
/**
* Set whether or not this Robot automatically calls {@link
- * waitForIdle} after generating an event.
+ * #waitForIdle()} after generating an event.
*
* @param isOn true if waitForIdle should be called automatically
*/
Index: kaffe/libraries/javalib/javax/swing/JTable.java
diff -u kaffe/libraries/javalib/javax/swing/JTable.java:1.23 kaffe/libraries/javalib/javax/swing/JTable.java:1.24
--- kaffe/libraries/javalib/javax/swing/JTable.java:1.23 Wed Jul 6 02:40:40 2005
+++ kaffe/libraries/javalib/javax/swing/JTable.java Wed Jul 6 13:21:17 2005
@@ -1421,13 +1421,20 @@
}
/**
* Set the value of the {@link #autoCreateColumnsFromModel} property.
*
* @param a The new value of the autoCreateColumnsFromModel property
*/
- public void setAutoCreateColumnsFromModel(boolean a)
+ public void setAutoCreateColumnsFromModel(boolean autoCreate)
{
- autoCreateColumnsFromModel = a;
+ if (autoCreateColumnsFromModel != autoCreate)
+ {
+ autoCreateColumnsFromModel = autoCreate;
+ if (autoCreate)
+ createDefaultColumnsFromModel();
+ }
}
/**
More information about the kaffe
@@ -1421,13 +1421,20 @@
}
/**
- * Set the value of the {@link #autoCreateColumnsFromModel} property.
+ * Set the value of the {@link #autoCreateColumnsFromModel} flag. If the
+ * flag changes from <code>false</code> to <code>true</code>, the
+ * {@link #createDefaultColumnsFromModel()} method is called.
*
@@ -1421,13 +1421,20 @@
*
- * @param a The new value of the autoCreateColumnsFromModel property
+ * @param autoCreate the new value of the flag.
*/
mailing list